@@ -15,7 +15,7 @@ from ._constants import _get_AU, _get_DAY2SEC, _get_DAY2YEAR, _get_DEG2RAD, _get
 # in this file, but we still want in the namespace core)
 
 
-"""Constants defined in SpaceMechanicsConstants.hpp"""
+"""Constants defined in HelioLibConstants.hpp"""
 AU = _get_AU()
 DAY2SEC = _get_DAY2SEC()
 DAY2YEAR = _get_DAY2YEAR()
